@@ -48,7 +48,7 @@ from rattail.db.model import (
     Brand, Vendor, Department, Subdepartment, LabelProfile)
 from rattail.gpc import GPC
 
-from .. import Session
+from ..db import Session
 from ..forms import AutocompleteFieldRenderer, GPCFieldRenderer, PriceFieldRenderer
 from . import CrudView
 
