@@ -30,7 +30,7 @@ from .core import View
 from mako.template import Template
 from pyramid.response import Response
 
-from .. import Session
+from ..db import Session
 from rattail.db.model import Vendor, Department, Product, ProductCost
 
 import re
